@@ -1109,7 +1109,9 @@ types: list[str] = [
     "AWS::SecretsManager::RotationSchedule",
     "AWS::SecretsManager::Secret",
     "AWS::SecretsManager::SecretTargetAttachment",
+    "AWS::SecurityHub::AggregatorV2",
     "AWS::SecurityHub::AutomationRule",
+    "AWS::SecurityHub::AutomationRuleV2",
     "AWS::SecurityHub::ConfigurationPolicy",
     "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::FindingAggregator",
@@ -1319,9 +1321,6 @@ cached: list[str] = [
     "aws-apprunner-service.json",
     "aws-apprunner-vpcconnector.json",
     "aws-apprunner-vpcingressconnection.json",
-    "aws-appstream-appblock.json",
-    "aws-appstream-appblockbuilder.json",
-    "aws-appstream-application.json",
     "aws-appstream-applicationentitlementassociation.json",
     "aws-appstream-applicationfleetassociation.json",
     "aws-appstream-directoryconfig.json",
@@ -1761,7 +1760,6 @@ cached: list[str] = [
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
     "aws-gamelift-alias.json",
-    "aws-gamelift-build.json",
     "aws-gamelift-fleet.json",
     "aws-gamelift-gameservergroup.json",
     "aws-gamelift-gamesessionqueue.json",
@@ -1950,6 +1948,7 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
+    "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
@@ -2278,7 +2277,9 @@ cached: list[str] = [
     "aws-secretsmanager-rotationschedule.json",
     "aws-secretsmanager-secret.json",
     "aws-secretsmanager-secrettargetattachment.json",
+    "aws-securityhub-aggregatorv2.json",
     "aws-securityhub-automationrule.json",
+    "aws-securityhub-automationrulev2.json",
     "aws-securityhub-configurationpolicy.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-findingaggregator.json",
