@@ -1162,7 +1162,9 @@ types: list[str] = [
     "AWS::SecretsManager::RotationSchedule",
     "AWS::SecretsManager::Secret",
     "AWS::SecretsManager::SecretTargetAttachment",
+    "AWS::SecurityHub::AggregatorV2",
     "AWS::SecurityHub::AutomationRule",
+    "AWS::SecurityHub::AutomationRuleV2",
     "AWS::SecurityHub::ConfigurationPolicy",
     "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::FindingAggregator",
@@ -1386,9 +1388,6 @@ cached: list[str] = [
     "aws-apprunner-service.json",
     "aws-apprunner-vpcconnector.json",
     "aws-apprunner-vpcingressconnection.json",
-    "aws-appstream-appblock.json",
-    "aws-appstream-appblockbuilder.json",
-    "aws-appstream-application.json",
     "aws-appstream-applicationentitlementassociation.json",
     "aws-appstream-applicationfleetassociation.json",
     "aws-appstream-directoryconfig.json",
@@ -2042,6 +2041,7 @@ cached: list[str] = [
     "aws-lambda-alias.json",
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
+    "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
@@ -2163,6 +2163,7 @@ cached: list[str] = [
     "aws-neptunegraph-privategraphendpoint.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
+    "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
@@ -2397,7 +2398,9 @@ cached: list[str] = [
     "aws-secretsmanager-rotationschedule.json",
     "aws-secretsmanager-secret.json",
     "aws-secretsmanager-secrettargetattachment.json",
+    "aws-securityhub-aggregatorv2.json",
     "aws-securityhub-automationrule.json",
+    "aws-securityhub-automationrulev2.json",
     "aws-securityhub-configurationpolicy.json",
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-findingaggregator.json",
