@@ -89,7 +89,9 @@ types: list[str] = [
     "AWS::Backup::BackupPlan",
     "AWS::Backup::BackupSelection",
     "AWS::Backup::BackupVault",
+    "AWS::Backup::Framework",
     "AWS::Backup::LogicallyAirGappedBackupVault",
+    "AWS::Backup::ReportPlan",
     "AWS::Backup::RestoreTestingPlan",
     "AWS::Backup::RestoreTestingSelection",
     "AWS::Batch::ComputeEnvironment",
@@ -863,7 +865,9 @@ cached: list[str] = [
     "aws-backup-backupplan.json",
     "aws-backup-backupselection.json",
     "aws-backup-backupvault.json",
+    "aws-backup-framework.json",
     "aws-backup-logicallyairgappedbackupvault.json",
+    "aws-backup-reportplan.json",
     "aws-backup-restoretestingplan.json",
     "aws-backup-restoretestingselection.json",
     "aws-batch-computeenvironment.json",
@@ -985,8 +989,6 @@ cached: list[str] = [
     "aws-ec2-clientvpntargetnetworkassociation.json",
     "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
-    "aws-ec2-ec2fleet.json",
-    "aws-ec2-egressonlyinternetgateway.json",
     "aws-ec2-eip.json",
     "aws-ec2-eipassociation.json",
     "aws-ec2-flowlog.json",
@@ -1027,7 +1029,6 @@ cached: list[str] = [
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
-    "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorfilterrule.json",
     "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
@@ -1225,6 +1226,7 @@ cached: list[str] = [
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
+    "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
@@ -1256,6 +1258,7 @@ cached: list[str] = [
     "aws-medialive-multiplex.json",
     "aws-medialive-multiplexprogram.json",
     "aws-medialive-signalmap.json",
+    "aws-mediapackage-asset.json",
     "aws-mediapackage-packagingconfiguration.json",
     "aws-mediapackage-packaginggroup.json",
     "aws-mediapackagev2-channel.json",
